@@ -1,7 +1,7 @@
 package App::fatten;
 
 our $DATE = '2015-04-15'; # DATE
-our $VERSION = '0.34'; # VERSION
+our $VERSION = '0.35'; # VERSION
 
 use 5.010001;
 use strict;
@@ -16,6 +16,8 @@ use File::chdir;
 use File::Slurper qw(write_text read_text);
 use version;
 
+my @ALLOW_XS = qw(List::MoreUtils version::vxs);
+
 sub __sq {
     require String::ShellQuote;
     String::ShellQuote::shell_quote($_[0]);
@@ -81,6 +83,8 @@ sub _trace {
 }
 
 sub _build_lib {
+    use experimental 'smartmatch';
+
     require Dist::Util;
     require File::Copy;
     require File::Find;
@@ -227,7 +231,10 @@ sub _build_lib {
 
         unless ($mpath) {
             if (Module::XSOrPP::is_xs($mod)) {
-                die "Can't add XS module: $mod\n";
+                unless (!$self->{allow_xs} || $mod ~~ @{ $self->{allow_xs} } ||
+                            $mod ~~ @ALLOW_XS) {
+                    die "Can't add XS module: $mod\n";
+                }
             }
         }
 
@@ -561,6 +568,10 @@ is available.
 _
             tags => ['category:module-selection'],
         },
+        allow_xs => {
+            'summary.alt.plurality.singular' => 'Allow adding a specified XS module',
+            schema => ['array*', of=>'str*'],
+        },
         use => {
             summary => 'Additional modules to "use"',
             'summary.alt.plurality.singular' => 'Additional module to "use"',
@@ -872,7 +883,7 @@ App::fatten - Pack your dependencies onto your script file
 
 =head1 VERSION
 
-This document describes version 0.34 of App::fatten (from Perl distribution App-fatten), released on 2015-04-15.
+This document describes version 0.35 of App::fatten (from Perl distribution App-fatten), released on 2015-04-15.
 
 =head1 SYNOPSIS
 
@@ -910,6 +921,8 @@ cannot fatpack XS modules.
 This option requires that C<lcpan> is installed and a fairly recent lcpan index
 is available.
 
+=item * B<allow_xs> => I<array[str]>
+
 =item * B<args> => I<array[str]>
 
 Script arguments.
